==> ogc-5.5.2-en-download.zip: ogc-5.5.2-en/webhelp/ogc-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entireoperationsguiclient
//
//	Copyright (c) 2016-2024 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entireoperationsguiclient = {
    baseurls: ["../"],
    varname: "entireoperationsguiclient",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "cnf/cnf-over_0001.htm", title: "Concepts and Facilities",
              tree: [
                  { url: "cnf/nop_introduction.htm", title: "Introducing Entire Operations" },
                  { url: "cnf/overview_components.htm", title: "Overview of Entire Operations Components" },
                  { url: "cnf/maintenance_objects.htm", title: "Entire Operations Maintenance Objects" },
                  { url: "cnf/Monitor.htm", title: "Entire Operations Monitor" },
                  { url: "cnf/master_active_database.htm", title: "Master Database and Active Database" },
                  { url: "cnf/Operating_System.htm", title: "Operating System" },
                  { url: "cnf/tools_utilities.htm", title: "Tools and Utilities" },
                  { url: "cnf/apis_exits.htm", title: "APIs and User Exits" },
              ]
            },
            { url: "rnotes/rnotes.htm", title: "Entire Operations Version 5.5.2 CF 11 Release Notes" },
            { url: "insops/insops-over_0001.htm", title: "Installation and Setup",
              tree: [
                  { url: "insops/ogc_install.htm", title: "Installing and Configuring Entire Operations GUI Client" },
              ]
            },
            { url: "admin/admin-over_0001.htm", title: "Administration",
              tree: [
                  { url: "admin/access_admin.htm", title: "Accessing Administration Functions" },
                  { url: "admin/user_0020.htm", title: "User Maintenance" },
                  { url: "admin/entiremo_0120.htm", title: "Entire Operations Monitor" },
                  { url: "admin/definit_0130.htm", title: "Definition of Nodes" },
                  { url: "admin/entirede_0140.htm", title: "Entire Operations Defaults" },
                  { url: "admin/monitor_0230.htm", title: "Monitor Defaults" },
                  { url: "admin/admin_monitor_accounting.htm", title: "Monitor Accounting" },
                  { url: "admin/messex.htm", title: "Global Messages and Exits" },
                  { url: "admin/globmessev_0240.htm", title: "Global Messages for Events" },
                  { url: "admin/globusexit_0250.htm", title: "Global User Exits" },
                  { url: "admin/global_0260.htm", title: "Global Message Code Table" },
                  { url: "admin/resource_0270.htm", title: "Resources" },
                  { url: "admin/mailbox_0310.htm", title: "Mailbox Definition" },
                  { url: "admin/special_0330.htm", title: "Special Monitor Functions and Batch Jobs" },
                  { url: "admin/rpcserverdef_0455.htm", title: "RPC Server Defaults" },
                  { url: "admin/admin_system_files.htm", title: "Entire Operations Files" },
              ]
            },
            { url: "ug/ug-over_0001.htm", title: "User's Guide",
              tree: [
                  { url: "ug/log_0480.htm", title: "Using Entire Operations GUI Client in Online Mode",
                    tree: [
                        { url: "ug/start_end_session.htm", title: "Starting and Ending an Entire Operations Session" },
                        { url: "ug/nop_os_userids.htm", title: "Entire Operations and Operating System User IDs" },
                        { url: "ug/user_language.htm", title: "User Language" },
                        { url: "ug/help_messages.htm", title: "Online Help and System Messages" },
                        { url: "ug/logosservnod_0500.htm", title: "Logging on and off an Operating System Server Node" },
                        { url: "ug/ch_window.htm", title: "Elements of the Main Application Window" },
                        { url: "ug/gen_functions_win.htm", title: "Common and Global Functions" },
                        { url: "ug/Op_Sys_Designations.htm", title: "Operating System Classes and Related Operating Systems" },
                        { url: "ug/Date_Time_Formats.htm", title: "Date and Time Formats" },
                    ]
                  },
                  { url: "ug/over_0020.htm", title: "Using the Entire Operations Business Functionality" },
                  { url: "ug/nop_utilities.htm", title: "Entire Operations Utilities" },
                  { url: "ug/batch_mode_ogc.htm", title: "Using Entire Operations in Batch Mode" },
                  { url: "ug/ch_owner.htm", title: "Owner Maintenance" },
                  { url: "ug/nets_0550.htm", title: "Network Maintenance",
                    tree: [
                        { url: "ug/net_use.htm", title: "Use of Job Networks" },
                        { url: "ug/sub-networks.htm", title: "Subnetworks" },
                        { url: "ug/invnetmaint_0560.htm", title: "Maintaining Job Network Definitions" },
                        { url: "ug/scheduling_network.htm", title: "Scheduling a Network" },
                        { url: "ug/maintain_network_versions.htm", title: "Maintaining Job Network Versions" },
                        { url: "ug/copyjobnetdef_0690.htm", title: "Copying Job Network Definitions" },
                        { url: "ug/dispovjobflownet_0710.htm", title: "Viewing and Maintaining a Job Network Diagram" },
                        { url: "ug/actjobnetman_0770.htm", title: "Activating a Job Network Manually" },
                        { url: "ug/chkloopjobnet_0730.htm", title: "Checking for a Loop in a Job Network" },
                        { url: "ug/copy_defaults_command.htm", title: "Applying Network Defaults to Jobs (Mass Update)" },
                    ]
                  },
                  { url: "ug/job_0930.htm", title: "Job Maintenance",
                    tree: [
                        { url: "ug/job_use.htm", title: "Use of Jobs" },
                        { url: "ug/define_manage_jobs.htm", title: "Maintaining Jobs" },
                        { url: "ug/use_job_types.htm", title: "Defining Job Types and Job Execution Features" },
                        { url: "ug/job_execution_dummy_epilog.htm", title: "Executing a Job as Dummy or Including Epilog Scripts" },
                        { url: "ug/use_dummy_job.htm", title: "Using a Dummy Job" },
                        { url: "ug/defsubnet_0990.htm", title: "Defining a Subnetwork" },
                        { url: "ug/def_para_ftp.htm", title: "Defining Parameters for an FTP Job" },
                        { url: "ug/define_manage_jcl.htm", title: "Defining and Managing JCL for a Job" },
                        { url: "ug/edit_jcl_sources.htm", title: "Editing Master JCL and Natural Sources" },
                        { url: "ug/define_manage_conditions.htm", title: "Defining and Managing Job Conditions" },
                        { url: "ug/handle_job_prereq_resource.htm", title: "Handling Prerequisite Resources for a Job" },
                        { url: "ug/define_eoj_events_actions.htm", title: "Defining and Managing End-of-Job (EOJ) Checking and Actions" },
                        { url: "ug/schedjob_0900.htm", title: "Scheduling a Job" },
                        { url: "ug/passing_1590.htm", title: "Passing Files to Entire Output Management" },
                        { url: "ug/view_accounting_data.htm", title: "Viewing Job/Network Accounting Information" },
                    ]
                  },
                  { url: "ug/active_job_net_maintenance.htm", title: "Active Job Network and Active Job Maintenance",
                    tree: [
                        { url: "ug/active_job_net_use.htm", title: "Meaning and Use of Active Job Networks and Active Jobs in Entire Operations" },
                        { url: "ug/job_network_activation.htm", title: "Activation of Networks or Jobs" },
                        { url: "ug/prerequisite_check.htm", title: "Prerequisite Check before Job Submission" },
                        { url: "ug/ajdmess_0140.htm", title: "Messages in Active Jobs Lists" },
                        { url: "ug/act_job_nets_maintenance.htm", title: "Maintaining Active Job Networks" },
                        { url: "ug/active_jobs_maintenance.htm", title: "Maintaining Active Jobs" },
                        { url: "ug/maint_active_conditions.htm", title: "Maintaining Active Job Conditions" },
                        { url: "ug/maint_active_jcl.htm", title: "Maintaining Active JCL (Job Control Language)" },
                    ]
                  },
                  { url: "ug/sched_0810.htm", title: "Schedule Maintenance",
                    tree: [
                        { url: "ug/genschedcons_0820.htm", title: "General Scheduling Considerations" },
                        { url: "ug/maintain_schedule_master.htm", title: "Maintaining a Schedule Master" },
                    ]
                  },
                  { url: "ug/cal_2090.htm", title: "Calendar Maintenance" },
                  { url: "ug/mail_2580.htm", title: "Mailboxes" },
                  { url: "ug/symbol_table_maintenance.htm", title: "Symbol Table and Symbol Maintenance",
                    tree: [
                        { url: "ug/symbols_general.htm", title: "Purpose and Use of Symbol Tables and Symbols" },
                        { url: "ug/maintain_find_symbol_tables.htm", title: "Maintaining and Finding Symbol Tables" },
                        { url: "ug/define_symbols.htm", title: "Defining Symbols and Symbol Values" },
                        { url: "ug/symbol_replacement.htm", title: "Symbol Replacement" },
                        { url: "ug/symbol_functions.htm", title: "Functions for Symbol Replacement" },
                    ]
                  },
                  { url: "ug/login_2190.htm", title: "Log Information" },
                  { url: "ug/reports.htm", title: "Reporting" },
                  { url: "ug/cross_ref.htm", title: "Cross-References" },
                  { url: "ug/api_2740.htm", title: "API Routines",
                    tree: [
                        { url: "ug/api_purpose.htm", title: "Purpose and Use of Entire Operations APIs" },
                        { url: "ug/listavapirout_2760.htm", title: "Available Entire Operations API Routines" },
                    ]
                  },
                  { url: "ug/userrou_0250.htm", title: "User Exits" },
              ]
            },
            { url: "uti/uti-over_0001.htm", title: "Import/Export Functions",
              tree: [
                  { url: "uti/gen_info.htm", title: "General Purpose and Backward Compatibility" },
                  { url: "uti/use_import_export.htm", title: "Using Import and Export Functions" },
                  { url: "uti/syntax_files.htm", title: "Syntax in Import/Export Files and Object Processing Rules" },
                  { url: "uti/object_specification.htm", title: "Object Specification" },
              ]
            },
            { url: "ref/direct_cmds_over.htm", title: "Direct Commands",
              tree: [
                  { url: "ref/dir_cmds_syntax.htm", title: "Direct Command Syntax" },
                  { url: "ref/direct_cmds.htm", title: "Direct Commands in Alphabetical Order" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entireoperationsguiclient });

==> ogc-5.5.3-en-download.zip: ogc-5.5.3-en/webhelp/ogc-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entireoperationsguiclient
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entireoperationsguiclient = {
    baseurls: ["../"],
    varname: "entireoperationsguiclient",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "cnf/cnf-over_0001.htm", title: "Concepts and Facilities",
              tree: [
                  { url: "cnf/nop_introduction.htm", title: "Introducing Entire Operations" },
                  { url: "cnf/overview_components.htm", title: "Overview of Entire Operations Components" },
                  { url: "cnf/maintenance_objects.htm", title: "Entire Operations Maintenance Objects" },
                  { url: "cnf/Monitor.htm", title: "Entire Operations Monitor" },
                  { url: "cnf/master_active_database.htm", title: "Master Database and Active Database" },
                  { url: "cnf/Operating_System.htm", title: "Operating System" },
                  { url: "cnf/tools_utilities.htm", title: "Tools and Utilities" },
                  { url: "cnf/apis_exits.htm", title: "APIs and User Exits" },
              ]
            },
            { url: "rnotes/rnotes.htm", title: "Entire Operations Version 5.5.3 Release Notes" },
            { url: "insops/insops-over_0001.htm", title: "Installation and Setup",
              tree: [
                  { url: "insops/ogc_install.htm", title: "Installing and Configuring Entire Operations GUI Client" },
              ]
            },
            { url: "admin/admin-over_0001.htm", title: "Administration",
              tree: [
                  { url: "admin/access_admin.htm", title: "Accessing Administration Functions" },
                  { url: "admin/user_0020.htm", title: "User Maintenance" },
                  { url: "admin/entiremo_0120.htm", title: "Entire Operations Monitor" },
                  { url: "admin/definit_0130.htm", title: "Definition of Nodes" },
                  { url: "admin/entirede_0140.htm", title: "Entire Operations Defaults" },
                  { url: "admin/monitor_0230.htm", title: "Monitor Defaults" },
                  { url: "admin/admin_monitor_accounting.htm", title: "Monitor Accounting" },
                  { url: "admin/messex.htm", title: "Global Messages and Exits" },
                  { url: "admin/globmessev_0240.htm", title: "Global Messages for Events" },
                  { url: "admin/globusexit_0250.htm", title: "Global User Exits" },
                  { url: "admin/global_0260.htm", title: "Global Message Code Table" },
                  { url: "admin/resource_0270.htm", title: "Resources" },
                  { url: "admin/mailbox_0310.htm", title: "Mailbox Definition" },
                  { url: "admin/special_0330.htm", title: "Special Monitor Functions and Batch Jobs" },
                  { url: "admin/rpcserverdef_0455.htm", title: "RPC Server Defaults" },
                  { url: "admin/admin_system_files.htm", title: "Entire Operations Files" },
              ]
            },
            { url: "ug/ug-over_0001.htm", title: "User's Guide",
              tree: [
                  { url: "ug/log_0480.htm", title: "Using Entire Operations GUI Client in Online Mode",
                    tree: [
                        { url: "ug/start_end_session.htm", title: "Starting and Ending an Entire Operations Session" },
                        { url: "ug/nop_os_userids.htm", title: "Entire Operations and Operating System User IDs" },
                        { url: "ug/user_language.htm", title: "User Language" },
                        { url: "ug/help_messages.htm", title: "Online Help and System Messages" },
                        { url: "ug/logosservnod_0500.htm", title: "Logging on and off an Operating System Server Node" },
                        { url: "ug/ch_window.htm", title: "Elements of the Main Application Window" },
                        { url: "ug/gen_functions_win.htm", title: "Common and Global Functions" },
                        { url: "ug/Op_Sys_Designations.htm", title: "Operating System Classes and Related Operating Systems" },
                        { url: "ug/Date_Time_Formats.htm", title: "Date and Time Formats" },
                    ]
                  },
                  { url: "ug/over_0020.htm", title: "Using the Entire Operations Business Functionality" },
                  { url: "ug/nop_utilities.htm", title: "Entire Operations Utilities" },
                  { url: "ug/batch_mode_ogc.htm", title: "Using Entire Operations in Batch Mode" },
                  { url: "ug/ch_owner.htm", title: "Owner Maintenance" },
                  { url: "ug/nets_0550.htm", title: "Network Maintenance",
                    tree: [
                        { url: "ug/net_use.htm", title: "Use of Job Networks" },
                        { url: "ug/sub-networks.htm", title: "Subnetworks" },
                        { url: "ug/invnetmaint_0560.htm", title: "Maintaining Job Network Definitions" },
                        { url: "ug/scheduling_network.htm", title: "Scheduling a Network" },
                        { url: "ug/maintain_network_versions.htm", title: "Maintaining Job Network Versions" },
                        { url: "ug/copyjobnetdef_0690.htm", title: "Copying Job Network Definitions" },
                        { url: "ug/dispovjobflownet_0710.htm", title: "Viewing and Maintaining a Job Network Diagram" },
                        { url: "ug/actjobnetman_0770.htm", title: "Activating a Job Network Manually" },
                        { url: "ug/chkloopjobnet_0730.htm", title: "Checking for a Loop in a Job Network" },
                        { url: "ug/copy_defaults_command.htm", title: "Applying Network Defaults to Jobs (Mass Update)" },
                    ]
                  },
                  { url: "ug/job_0930.htm", title: "Job Maintenance",
                    tree: [
                        { url: "ug/job_use.htm", title: "Use of Jobs" },
                        { url: "ug/define_manage_jobs.htm", title: "Maintaining Jobs" },
                        { url: "ug/use_job_types.htm", title: "Defining Job Types and Job Execution Features" },
                        { url: "ug/job_execution_dummy_epilog.htm", title: "Executing a Job as Dummy or Including Epilog Scripts" },
                        { url: "ug/use_dummy_job.htm", title: "Using a Dummy Job" },
                        { url: "ug/defsubnet_0990.htm", title: "Defining a Subnetwork" },
                        { url: "ug/def_para_ftp.htm", title: "Defining Parameters for an FTP Job" },
                        { url: "ug/define_manage_jcl.htm", title: "Defining and Managing JCL for a Job" },
                        { url: "ug/edit_jcl_sources.htm", title: "Editing Master JCL and Natural Sources" },
                        { url: "ug/define_manage_conditions.htm", title: "Defining and Managing Job Conditions" },
                        { url: "ug/handle_job_prereq_resource.htm", title: "Handling Prerequisite Resources for a Job" },
                        { url: "ug/define_eoj_events_actions.htm", title: "Defining and Managing End-of-Job (EOJ) Checking and Actions" },
                        { url: "ug/schedjob_0900.htm", title: "Scheduling a Job" },
                        { url: "ug/passing_1590.htm", title: "Passing Files to Entire Output Management" },
                        { url: "ug/view_accounting_data.htm", title: "Viewing Job/Network Accounting Information" },
                    ]
                  },
                  { url: "ug/active_job_net_maintenance.htm", title: "Active Job Network and Active Job Maintenance",
                    tree: [
                        { url: "ug/active_job_net_use.htm", title: "Meaning and Use of Active Job Networks and Active Jobs in Entire Operations" },
                        { url: "ug/job_network_activation.htm", title: "Activation of Networks or Jobs" },
                        { url: "ug/prerequisite_check.htm", title: "Prerequisite Check before Job Submission" },
                        { url: "ug/ajdmess_0140.htm", title: "Messages in Active Jobs Lists" },
                        { url: "ug/act_job_nets_maintenance.htm", title: "Maintaining Active Job Networks" },
                        { url: "ug/active_jobs_maintenance.htm", title: "Maintaining Active Jobs" },
                        { url: "ug/maint_active_conditions.htm", title: "Maintaining Active Job Conditions" },
                        { url: "ug/maint_active_jcl.htm", title: "Maintaining Active JCL (Job Control Language)" },
                    ]
                  },
                  { url: "ug/sched_0810.htm", title: "Schedule Maintenance",
                    tree: [
                        { url: "ug/genschedcons_0820.htm", title: "General Scheduling Considerations" },
                        { url: "ug/maintain_schedule_master.htm", title: "Maintaining a Schedule Master" },
                    ]
                  },
                  { url: "ug/cal_2090.htm", title: "Calendar Maintenance" },
                  { url: "ug/mail_2580.htm", title: "Mailboxes" },
                  { url: "ug/symbol_table_maintenance.htm", title: "Symbol Table and Symbol Maintenance",
                    tree: [
                        { url: "ug/symbols_general.htm", title: "Purpose and Use of Symbol Tables and Symbols" },
                        { url: "ug/maintain_find_symbol_tables.htm", title: "Maintaining and Finding Symbol Tables" },
                        { url: "ug/define_symbols.htm", title: "Defining Symbols and Symbol Values" },
                        { url: "ug/symbol_replacement.htm", title: "Symbol Replacement" },
                        { url: "ug/symbol_functions.htm", title: "Functions for Symbol Replacement" },
                    ]
                  },
                  { url: "ug/login_2190.htm", title: "Log Information" },
                  { url: "ug/reports.htm", title: "Reporting" },
                  { url: "ug/cross_ref.htm", title: "Cross-References" },
                  { url: "ug/api_2740.htm", title: "API Routines",
                    tree: [
                        { url: "ug/api_purpose.htm", title: "Purpose and Use of Entire Operations APIs" },
                        { url: "ug/listavapirout_2760.htm", title: "Available Entire Operations API Routines" },
                    ]
                  },
                  { url: "ug/userrou_0250.htm", title: "User Exits" },
              ]
            },
            { url: "uti/uti-over_0001.htm", title: "Import/Export Functions",
              tree: [
                  { url: "uti/gen_info.htm", title: "General Purpose and Backward Compatibility" },
                  { url: "uti/use_import_export.htm", title: "Using Import and Export Functions" },
                  { url: "uti/syntax_files.htm", title: "Syntax in Import/Export Files and Object Processing Rules" },
                  { url: "uti/object_specification.htm", title: "Object Specification" },
              ]
            },
            { url: "ref/direct_cmds_over.htm", title: "Direct Commands",
              tree: [
                  { url: "ref/dir_cmds_syntax.htm", title: "Direct Command Syntax" },
                  { url: "ref/direct_cmds.htm", title: "Direct Commands in Alphabetical Order" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entireoperationsguiclient });
